/*
 * This file is part of Invenio.
 * Copyright (C) 2016-2018 CERN.
 *
 * Invenio is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

header .alert {
  margin-top: -$line-height-computed;
  border-radius: 0px;
}

header .frontpage-search {
  padding-bottom: 50px;

  h1 {
    color: $navbar-default-brand-color;
    padding-bottom: 15px;
  }
}
