/*
 * This file is part of Invenio.
 * Copyright (C) 2015-2018 CERN.
 *
 * Invenio is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

$navbar-height: 60px;
$brand-font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !default;
$brand-font-size: 30px;

$color1: rgba(13, 95, 137, 0.8);
$color1-gradient: lighten($color1, 15%);
$color2: #90C5A9;
$color3: #7A9A95;
$color4: #EF6D3B;
$color5: #FA8B60;

$navbar-default-toggle-icon-bar-bg: white;
$navbar-brand-padding-vertical: 10px;
$navbar-default-bg: $color1;
$navbar-default-brand-color: white;
$navbar-default-border: darken($navbar-default-bg, 10%);

$text-white: #fff;
