{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2017-2018 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{%- extends config.THEME_HEADER_TEMPLATE %}

{#- Remove search field from top bar on frontpage #}
{%- block navbar_search %}{% endblock %}

{%- block navbar_inner %}
{{super()}}
{%- block frontpage_search %}
<div class="row frontpage-search">
  <div class="col-md-12">
    {%- block frontpage_title %}
    <h1 class="text-center">
        {{_(config.THEME_FRONTPAGE_TITLE)}}
    </h1>
    {%- endblock frontpage_title %}
    {%- block frontpage_form %}
    <form action="/search">
      <div class="form-group">
        <div class="input-group">
          <input type="text" name="q" class="input-lg form-control" placeholder="{{ _("Type and press enter to search") }}">
          <div class="input-group-btn">
            <button type="submit" class="btn btn-lg btn-default"><i class="fa fa-search"></i></button>
          </div>
        </div>
      </div>
    </form>
    {%- endblock frontpage_form %}
  </div>
</div>
{%- endblock frontpage_search %}
{% endblock %}
