{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2017-2018 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{%- extends config.BASE_TEMPLATE %}

{%- block page_header %}
{%- include "invenio_theme/header_frontpage.html" %}
{%- endblock page_header %}

{%- block page_body %}
{%- endblock %}

