{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2015-2018 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}
<footer id="footer">
  <div class="container">
    <div class="row">
      <div class="col-xs-12"><hr /></div>
    </div>
    <div class="row">
      <div class="col-xs-6 col-xs-push-6 text-right">
        {%- if config.I18N_LANGUAGES %}
        {% from "invenio_i18n/macros/language_selector.html" import language_selector_dropdown %}
        {{ language_selector_dropdown() }}
        {%- endif %}
      </div>
      <div class="col-xs-6 col-xs-pull-6">
        {% trans link="http://inveniosoftware.org" %}Powered by <a href="{{link}}">Invenio</a>{% endtrans %}
      </div>
    </div>
  </div>
</footer>
